==> dhall-yaml-1.2.12-138-riscv64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-EGVYbkehsaAIwfOeGJotUT
key:                  dhall-yaml-1.2.12-EGVYbkehsaAIwfOeGJotUT
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  167a0f546da72119a75ef84aee8fbe5f
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-EGVYbkehsaAIwfOeGJotUT
depends:
    HsYAML-0.2.1.5-AY47TzqMj7dFpILzJx3YmV
    HsYAML-aeson-0.2.0.2-IxWwZSgkpeu4wRMD4Ng9OU
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    bytestring-0.11.5.3 dhall-1.42.3-4nYYNMOVNunEFpgl2kICyh
    dhall-json-1.7.12-4GFbXfWHFd4DzAskTLy2Cq
    optparse-applicative-0.18.1.0-3qYZezrQAxc4lJKAil0WN1 text-2.0.2
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-yaml-1.2.12-161-riscv64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-7aaEvYBmryfL9IEdPjVtFO
key:                  dhall-yaml-1.2.12-7aaEvYBmryfL9IEdPjVtFO
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  440863f86e4c6e0c29c929d174b5a1ed
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-7aaEvYBmryfL9IEdPjVtFO
depends:
    HsYAML-0.2.1.5-7lJjfdMoLby4Dod2BRPO1b
    HsYAML-aeson-0.2.0.2-F7VoyMeQXILLLOkWPYp246
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    bytestring-0.11.5.3 dhall-1.42.3-HeTEhICrwINHKsGOfVjnsv
    dhall-json-1.7.12-3G7taIDoeSW9B6eMftZMI2
    optparse-applicative-0.18.1.0-t4C6chS8YH5x9x9VuRkT0 text-2.0.2
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
